@@ -17,11 +17,11 @@ $.getStylesheet(
 );
 
 $.getStylesheet(
-  "https://fezvrasta.github.io/snackbarjs/themes-css/material.css"
+  "https://unpkg.com/snackbarjs@1.1.0/themes-css/material.css"
 );
 
 $.getStylesheet(
-  "https://fezvrasta.github.io/snackbarjs/dist/snackbar.min.css"
+  "https://unpkg.com/snackbarjs@1.1.0/dist/snackbar.min.css"
 );
 
 function randId() {
@@ -125,7 +125,7 @@ require.config({
     imjoyLoader: "https://lib.imjoy.io/imjoy-loader",
     vue: "https://cdn.jsdelivr.net/npm/vue@2.6.10/dist/vue.min",
     "vue-js-modal": "https://imjoy-team.github.io/vue-js-modal/index",
-    snackbar: "https://cdnjs.cloudflare.com/ajax/libs/snackbarjs/1.1.0/snackbar.min",
+    snackbar: "https://unpkg.com/snackbarjs@1.1.0/dist/snackbar.min",
     "codemirror/mode/htmlmixed/htmlmixed": "https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.57.0/mode/htmlmixed/htmlmixed.min",
     "codemirror/mode/javascript/javascript": "https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.57.0/mode/javascript/javascript.min",
     "codemirror/mode/css/css": "https://cdnjs.cloudflare.com/ajax/libs/codemirror/5.57.0/mode/css/css.min"
@@ -141,7 +141,7 @@ class Connection extends MessageEmitter {
       const data = msg.content.data;
       const buffer_paths = data.__buffer_paths__ || [];
       delete data.__buffer_paths__;
-      put_buffers(data, buffer_paths, msg.buffers || []);
+      putBuffers(data, buffer_paths, msg.buffers || []);
       if (data.type === "log" || data.type === "info") {
         console.log(data.message);
       } else if (data.type === "error") {
@@ -159,7 +159,7 @@ class Connection extends MessageEmitter {
   disconnect() {}
   emit(data) {
     data.peer_id = this._peer_id;
-    const split = remove_buffers(data);
+    const split = removeBuffers(data);
     split.state.__buffer_paths__ = split.buffer_paths;
     this.comm.send(split.state, {}, {}, split.buffers);
   }
@@ -223,13 +223,12 @@ async function startImJoy(app, imjoy) {
 }
 
 function setupComm(targetOrigin) {
-  console.log(Jupyter.notebook.kernel.comm_manager);
   const comm = Jupyter.notebook.kernel.comm_manager.new_comm("imjoy_rpc", {});
   comm.on_msg(msg => {
     const data = msg.content.data;
     const buffer_paths = data.__buffer_paths__ || [];
     delete data.__buffer_paths__;
-    put_buffers(data, buffer_paths, msg.buffers || []);
+    putBuffers(data, buffer_paths, msg.buffers || []);
 
     if (data.type === "log" || data.type === "info") {
       console.log(data.message);
@@ -247,7 +246,7 @@ function setupMessageHandler(targetOrigin, comm) {
   window.addEventListener("message", e => {
     if (targetOrigin === "*" || e.origin === targetOrigin) {
       const data = e.data;
-      const split = remove_buffers(data);
+      const split = removeBuffers(data);
       split.state.__buffer_paths__ = split.buffer_paths;
       comm.send(split.state, {}, {}, split.buffers);
     }
@@ -351,16 +350,21 @@ define([
         });
       });
     });
+    if (!window.document.getElementById('snackbar-container')) {
+      const snackbarElm = window.document.createElement('div');
+      snackbarElm.id = 'snackbar-container';
+      window.document.body.appendChild(snackbarElm);
+    }
     // check if it's inside an iframe
     // if yes, initialize the rpc connection
     if (window.self !== window.top) {
       initPlugin();
       window.connectPlugin = function () {
-        comm = setupComm("*");
+        const comm = setupComm("*");
         setupMessageHandler("*", comm);
         console.log("ImJoy RPC reloaded.");
       };
-      var elem = document.createElement("div");
+      const elem = document.createElement("div");
       elem.id = "app";
       elem.style.display = "inline-block"
       elem.innerHTML = `<button class="btn btn-default" onclick="connectPlugin()"><i class="fa-play fa"></i>&nbsp;<img src="https://imjoy.io/static/img/imjoy-logo-black.svg" style="height: 18px;"></button>`;
@@ -394,9 +398,7 @@ define([
           },
           mounted() {
             window.dispatchEvent(new Event('resize'));
-            imjoyLoder.loadImJoyCore({
-              version: '0.13.31'
-            }).then(imjoyCore => {
+            imjoyLoder.loadImJoyCore({version: "0.13.43"}).then(imjoyCore => {
               console.log(`ImJoy Core (v${imjoyCore.VERSION}) loaded.`)
               const imjoy = new imjoyCore.ImJoy({
                 imjoy_api: {
@@ -597,11 +599,11 @@ function isObject(value) {
   return value && typeof value === "object" && value.constructor === Object;
 }
 
-// pub_buffers and remove_buffers are taken from
+// pub_buffers and removeBuffers are taken from
 // https://github.com/jupyter-widgets/ipywidgets/blob/master/packages/base/src/utils.ts
 // Author: IPython Development Team
 // License: BSD
-function put_buffers(state, buffer_paths, buffers) {
+function putBuffers(state, buffer_paths, buffers) {
   buffers = buffers.map(b => {
     if (b instanceof DataView) {
       return b.buffer;
@@ -623,14 +625,14 @@ function put_buffers(state, buffer_paths, buffers) {
 }
 
 /**
- * The inverse of put_buffers, return an objects with the new state where all buffers(ArrayBuffer)
+ * The inverse of putBuffers, return an objects with the new state where all buffers(ArrayBuffer)
  * are removed. If a buffer is a member of an object, that object is cloned, and the key removed. If a buffer
  * is an element of an array, that array is cloned, and the element is set to null.
- * See put_buffers for the meaning of buffer_paths
+ * See putBuffers for the meaning of buffer_paths
  * Returns an object with the new state (.state) an array with paths to the buffers (.buffer_paths),
  * and the buffers associated to those paths (.buffers).
  */
-function remove_buffers(state) {
+function removeBuffers(state) {
   const buffers = [];
   const buffer_paths = [];
   // if we need to remove an object from a list, we need to clone that list, otherwise we may modify
